summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authordaniel oeh <daniel.oeh@gmail.com>2012-09-27 13:48:12 +0200
committerdaniel oeh <daniel.oeh@gmail.com>2012-09-27 13:48:12 +0200
commit1e8f31b979ae35eb7c0321c0d9717b92ea6e3940 (patch)
tree75d8eadade217b404f05d5c01f9d59f542bbe019 /src
parentc95c31f802d25a45bed3be12602a4b5d48dd65c5 (diff)
downloadAntennaPod-1e8f31b979ae35eb7c0321c0d9717b92ea6e3940.zip
Changed behavior of getIdentifyingValue()
Diffstat (limited to 'src')
-rw-r--r--src/de/danoeh/antennapod/feed/Feed.java8
-rw-r--r--src/de/danoeh/antennapod/feed/FeedItem.java10
2 files changed, 9 insertions, 9 deletions
diff --git a/src/de/danoeh/antennapod/feed/FeedItem.java b/src/de/danoeh/antennapod/feed/FeedItem.java
index 39a40e799..a8bb0dbb4 100644
--- a/src/de/danoeh/antennapod/feed/FeedItem.java
+++ b/src/de/danoeh/antennapod/feed/FeedItem.java
@@ -63,16 +63,16 @@ public class FeedItem extends FeedComponent {
/** Returns the value that uniquely identifies this FeedItem.
* If the itemIdentifier attribute is not null, it will be returned.
- * Else it will try to return the link. If the link is not given, it will
- * use the title of the entry.
+ * Else it will try to return the title. If the title is not given, it will
+ * use the link of the entry.
* */
public String getIdentifyingValue() {
if (itemIdentifier != null) {
return itemIdentifier;
- } else if (link != null) {
- return link;
- } else {
+ } else if (title != null) {
return title;
+ } else {
+ return link;
}
}
diff --git a/src/de/danoeh/antennapod/feed/Feed.java b/src/de/danoeh/antennapod/feed/Feed.java
index 9b68faab1..76f6a6fa5 100644
--- a/src/de/danoeh/antennapod/feed/Feed.java
+++ b/src/de/danoeh/antennapod/feed/Feed.java
@@ -122,14 +122,14 @@ public class Feed extends FeedFile {
/**
* Returns the value that uniquely identifies this Feed. If the
* feedIdentifier attribute is not null, it will be returned. Else it will
* try to return the link. If the link is not given, it will use the title
* of the entry.
* */
public String getIdentifyingValue() {
if (feedIdentifier != null) {
return feedIdentifier;
- } else if (link != null) {
- return link;
+ } else if (download_url != null) {
+ return download_url;
} else {
return title;
}
@@ -122,14 +122,14 @@ public class Feed extends FeedFile {
* Returns the value that uniquely identifies this Feed. If the
* feedIdentifier attribute is not null, it will be returned. Else it will
- * try to return the link. If the link is not given, it will use the title
- * of the entry.
+ * try to return the download URL. If the download URL is not given, it will use the title
+ * of the feed.
* */
public String getIdentifyingValue() {